@@ -25,8 +25,6 @@ srs_table = srs.read_srs(sunpy.data.sample.SRS_TABLE)
 
 ##############################################################################
 # We only need the rows which have 'ID' = 'I' or 'IA'.
-# Some tables do not have these columns, so we exit the script if they are not
-# present.
 
 srs_table = srs_table[np.logical_or(srs_table['ID'] == 'I', srs_table['ID'] == 'IA')]
 
@@ -48,16 +46,21 @@ numbers = srs_table['Number']
 ##############################################################################
 # Let's plot the results by defining coordinates for each location.
 
-ax = plt.subplot(projection=smap)
-smap.plot(vmin=-120, vmax=120)
-smap.draw_limb()
+fig = plt.figure()
+ax = fig.add_subplot(projection=smap)
+# Passing vmin/vmax to ``plot`` does not work since
+# a normalisation is set on the map. So we have to
+# work around it like so:
+smap.plot_settings["norm"].vmin = -150
+smap.plot_settings["norm"].vmax = 150
+smap.plot(axes=ax)
+smap.draw_limb(axes=ax)
 c = SkyCoord(lngs, lats, frame="heliographic_stonyhurst")
 ax.plot_coord(c, 'o')
 for num, lng, lat in zip(numbers, lngs.value, lats.value):
     ax.annotate(num, (lng, lat),
                 xycoords=ax.get_transform('heliographic_stonyhurst'),
                 color='red',
-                fontweight='bold',
-                )
+                fontweight='bold')
 
 plt.show()
