@@ -19,8 +19,8 @@ from astropy.units import equivalencies
 import sunpy
 import sunpy.net.vso.legacy_response
 from sunpy import config
+from sunpy.io import _fits
 from sunpy.io import file_tools as sunpy_filetools
-from sunpy.io import fits
 from sunpy.io.header import FileHeader
 from sunpy.time import parse_time
 from sunpy.util.types import DatabaseEntryType
@@ -102,7 +102,7 @@ class JSONDump(Base):
         return self.dump
 
     def __repr__(self):
-        return f'<{self.__class__.__name__}(dump {self.dump!r})>'
+        return f'{self.__class__.__name__}(dump={self.dump!r})'
 
 
 class FitsHeaderEntry(Base):
@@ -130,7 +130,7 @@ class FitsHeaderEntry(Base):
         return not (self == other)
 
     def __repr__(self):
-        return '<{}(id {}, key {!r}, value {!r})>'.format(
+        return '{}(id={}, key={!r}, value={!r})'.format(
             self.__class__.__name__, self.id, self.key, self.value)
 
 
@@ -163,7 +163,7 @@ class FitsKeyComment(Base):
         return not (self == other)
 
     def __repr__(self):
-        return '<{}(id {}, key {!r}, value {!r})>'.format(
+        return '{}(id={}, key={!r}, value={!r})>'.format(
             self.__class__.__name__, self.id, self.key, self.value)
 
 
@@ -188,7 +188,7 @@ class Tag(Base):
         return self.name
 
     def __repr__(self):
-        return f'<{self.__class__.__name__}(name {self.name!r})>'
+        return f'{self.__class__.__name__}(name={self.name!r})'
 
 
 class DatabaseEntry(DatabaseEntryType, Base):
@@ -474,13 +474,13 @@ class DatabaseEntry(DatabaseEntryType, Base):
             'observation_time_start', 'observation_time_end', 'instrument',
             'size', 'wavemin', 'wavemax', 'path', 'download_time', 'starred',
             'fits_header_entries', 'tags']
-        ret = f'<{self.__class__.__name__}('
+        ret = f'{self.__class__.__name__}('
         for attr in attrs:
             value = getattr(self, attr, None)
             if value:
-                ret += f'{attr} {value!r}, '
+                ret += f'{attr}={value!r}, '
         ret = ret.rstrip(', ')
-        ret += ')>'
+        ret += ')'
         return ret
 
 
@@ -642,7 +642,7 @@ def entries_from_file(file, default_waveunit=None,
     110
 
     """
-    headers = fits.get_header(file)
+    headers = _fits.get_header(file)
 
     # This just checks for blank default headers
     # due to compression.
@@ -667,7 +667,7 @@ def entries_from_file(file, default_waveunit=None,
                     entry.fits_key_comments.append(FitsKeyComment(k, v))
                 continue
             entry.fits_header_entries.append(FitsHeaderEntry(key, value))
-        waveunit = fits.extract_waveunit(header)
+        waveunit = _fits.extract_waveunit(header)
         entry.hdu_index = headers.index(header)
         if waveunit is None:
             waveunit = default_waveunit
