@@ -27,6 +27,7 @@ import sunpy.data.test
 import sunpy.map
 import sunpy.sun
 from sunpy.coordinates import HeliographicCarrington, HeliographicStonyhurst, sun
+from sunpy.image.transform import _rotation_registry
 from sunpy.map.mapbase import GenericMap
 from sunpy.map.sources import AIAMap
 from sunpy.tests.helpers import figure_test
@@ -116,19 +117,19 @@ def test_dtype(generic_map):
 
 
 def test_min(generic_map):
-    assert generic_map.min() == 1
+    assert generic_map.min() == 0
 
 
 def test_max(generic_map):
-    assert generic_map.max() == 1
+    assert generic_map.max() == 35
 
 
 def test_mean(generic_map):
-    assert generic_map.mean() == 1
+    assert generic_map.mean() == 17.5
 
 
 def test_std(generic_map):
-    assert generic_map.std() == 0
+    np.testing.assert_allclose(generic_map.std(), 10.388294694831615)
 
 
 def test_unit(generic_map):
@@ -259,7 +260,7 @@ def test_heliographic_longitude(generic_map):
 
 
 def test_units(generic_map):
-    generic_map.spatial_units == ('arcsec', 'arcsec')
+    assert generic_map.spatial_units == ('arcsec', 'arcsec')
 
 
 def test_cmap(generic_map):
@@ -464,6 +465,19 @@ def test_save_compressed(aia171_test_map):
     assert isinstance(loaded_save, sunpy.map.sources.AIAMap)
 
 
+DEP_WARNING_SHIFTED_VAL = (
+    'ignore:`sunpy.map.GenericMap.shifted_value` is deprecated and will be removed in sunpy 4.1. '
+    'Use ``sunpy.map.GenericMap.meta.modified_items`` to see how the reference coordinate has been '
+    'modified.:sunpy.util.exceptions.SunpyDeprecationWarning'
+)
+DEP_WARNING_SHIFT = (
+    'ignore:The shift function is deprecated and may be removed in version 4.1.'
+    r'\s+Use `sunpy.map.GenericMap.shift_reference_coord` instead.'
+    ':sunpy.util.exceptions.SunpyDeprecationWarning'
+)
+
+
+@pytest.mark.filterwarnings(DEP_WARNING_SHIFTED_VAL)
 def test_default_shift():
     """Test that the default shift is zero"""
     data = np.ones([6, 6], dtype=np.float64)
@@ -490,6 +504,8 @@ def test_default_shift():
     assert cd_map.shifted_value[1].value == 0
 
 
+@pytest.mark.filterwarnings(DEP_WARNING_SHIFT)
+@pytest.mark.filterwarnings(DEP_WARNING_SHIFTED_VAL)
 def test_shift_applied(generic_map):
     """Test that adding a shift actually updates the reference coordinate"""
     original_reference_coord = (generic_map.reference_coordinate.Tx,
@@ -500,23 +516,28 @@ def test_shift_applied(generic_map):
     assert shifted_map.reference_coordinate.Tx - x_shift == original_reference_coord[0]
     assert shifted_map.reference_coordinate.Ty - y_shift == original_reference_coord[1]
     crval1 = ((generic_map.meta.get('crval1') * generic_map.spatial_units[0] +
-               shifted_map.shifted_value[0]).to(shifted_map.spatial_units[0])).value
+               x_shift).to(shifted_map.spatial_units[0])).value
     assert shifted_map.meta.get('crval1') == crval1
     crval2 = ((generic_map.meta.get('crval2') * generic_map.spatial_units[1] +
-               shifted_map.shifted_value[1]).to(shifted_map.spatial_units[1])).value
+               y_shift).to(shifted_map.spatial_units[1])).value
     assert shifted_map.meta.get('crval2') == crval2
 
 
+@pytest.mark.filterwarnings(DEP_WARNING_SHIFT)
+@pytest.mark.filterwarnings(DEP_WARNING_SHIFTED_VAL)
 def test_set_shift(generic_map):
     """Test that previously applied shift is stored in the shifted_value property"""
     x_shift = 5 * u.arcsec
     y_shift = 13 * u.arcsec
     shifted_map = generic_map.shift(x_shift, y_shift)
-    resultant_shift = shifted_map.shifted_value
-    assert resultant_shift[0] == x_shift
-    assert resultant_shift[1] == y_shift
+    mod_crval1 = shifted_map.meta.modified_items['crval1']
+    mod_crval2 = shifted_map.meta.modified_items['crval2']
+    assert x_shift == (mod_crval1.current - mod_crval1.original) * shifted_map.spatial_units[0]
+    assert y_shift == (mod_crval2.current - mod_crval2.original) * shifted_map.spatial_units[1]
 
 
+@pytest.mark.filterwarnings(DEP_WARNING_SHIFT)
+@pytest.mark.filterwarnings(DEP_WARNING_SHIFTED_VAL)
 def test_shift_history(generic_map):
     """Test the shifted_value is added to a non-zero previous shift"""
     x_shift1 = 5 * u.arcsec
@@ -527,9 +548,12 @@ def test_shift_history(generic_map):
     y_shift2 = 120 * u.arcsec
     final_shifted_map = shifted_map1.shift(x_shift2, y_shift2)
 
-    resultant_shift = final_shifted_map.shifted_value
-    assert resultant_shift[0] == x_shift1 + x_shift2
-    assert resultant_shift[1] == y_shift1 + y_shift2
+    mod_crval1 = final_shifted_map.meta.modified_items['crval1']
+    mod_crval2 = final_shifted_map.meta.modified_items['crval2']
+    delta_crval1 = (mod_crval1.current - mod_crval1.original) * final_shifted_map.spatial_units[0]
+    delta_crval2 = (mod_crval2.current - mod_crval2.original) * final_shifted_map.spatial_units[1]
+    assert x_shift1 + x_shift2 == delta_crval1
+    assert y_shift1 + y_shift2 == delta_crval2
 
 
 def test_corners(simple_map):
@@ -752,61 +776,54 @@ def test_superpixel_simple_map(simple_map):
     # Make the superpixel map
     new_dims = (2, 2) * u.pix
     superpix_map = simple_map.superpixel(new_dims)
-    # Reference pixel should change, but referenc coordinate should not
+    # Reference pixel should change, but reference coordinate should not
     assert list(superpix_map.reference_pixel) == [0 * u.pix, 0 * u.pix]
     assert superpix_map.reference_coordinate == simple_map.reference_coordinate
 
     # Check that offset works
     superpix_map = simple_map.superpixel(new_dims, offset=[1, 2] * u.pix)
-    # Reference pixel should change, but referenc coordinate should not
+    # Reference pixel should change, but reference coordinate should not
     assert u.allclose(list(superpix_map.reference_pixel),
                       [-0.5 * u.pix, -1 * u.pix])
     assert superpix_map.reference_coordinate == simple_map.reference_coordinate
 
 
-def test_superpixel(aia171_test_map, aia171_test_map_with_mask):
+@pytest.mark.parametrize('f', [np.sum, np.mean])
+def test_superpixel_dims_values(aia171_test_map, f):
     dimensions = (2, 2) * u.pix
-    superpixel_map_sum = aia171_test_map.superpixel(dimensions)
-    assert_quantity_allclose(superpixel_map_sum.dimensions[1],
-                             aia171_test_map.dimensions[1] / dimensions[1] * u.pix)
-    assert_quantity_allclose(superpixel_map_sum.dimensions[0],
-                             aia171_test_map.dimensions[0] / dimensions[0] * u.pix)
-    assert_quantity_allclose(superpixel_map_sum.data[0][0],
-                             (aia171_test_map.data[0][0] + aia171_test_map.data[0][1] +
-                              aia171_test_map.data[1][0] + aia171_test_map.data[1][1]))
+    superpix_map = aia171_test_map.superpixel(dimensions, func=f)
 
-    superpixel_map_avg = aia171_test_map.superpixel(dimensions, func=np.mean)
-    assert_quantity_allclose(superpixel_map_avg.dimensions[1],
-                             aia171_test_map.dimensions[1] / dimensions[1] * u.pix)
-    assert_quantity_allclose(superpixel_map_avg.dimensions[0],
-                             aia171_test_map.dimensions[0] / dimensions[0] * u.pix)
-    assert_quantity_allclose(superpixel_map_avg.data[0][0],
-                             (aia171_test_map.data[0][0] + aia171_test_map.data[0][1] +
-                              aia171_test_map.data[1][0] + aia171_test_map.data[1][1]) / 4.0)
+    # Check dimensions of new map
+    old_dims = u.Quantity(aia171_test_map.dimensions)
+    expected_new_dims = old_dims * (1 * u.pix / dimensions)
+    assert superpix_map.dimensions[0] == expected_new_dims[0]
+    assert superpix_map.dimensions[1] == expected_new_dims[1]
 
+    # Check value of lower left pixel is calculated correctly
+    expected = f(aia171_test_map.data[0:2, 0:2])
+    assert_quantity_allclose(superpix_map.data[0, 0], expected)
+
+
+def test_superpixel_masked(aia171_test_map_with_mask):
+    input_dims = u.Quantity(aia171_test_map_with_mask.dimensions)
+    dimensions = (2, 2) * u.pix
     # Test that the mask is respected
-    superpixel_map_sum = aia171_test_map_with_mask.superpixel(dimensions)
-    assert superpixel_map_sum.mask is not None
-    assert_quantity_allclose(superpixel_map_sum.mask.shape[0],
-                             aia171_test_map.dimensions[1] / dimensions[1])
-    assert_quantity_allclose(superpixel_map_sum.mask.shape[1],
-                             aia171_test_map.dimensions[0] / dimensions[0])
+    superpix_map = aia171_test_map_with_mask.superpixel(dimensions)
+    assert superpix_map.mask is not None
+    # Check the shape of the mask
+    expected_shape = input_dims * (1 * u.pix / dimensions)
+    assert np.all(superpix_map.mask.shape * u.pix == expected_shape)
 
     # Test that the offset is respected
-    superpixel_map_sum = aia171_test_map_with_mask.superpixel(dimensions, offset=(1, 1) * u.pix)
-    assert_quantity_allclose(superpixel_map_sum.dimensions[1],
-                             aia171_test_map.dimensions[1] / dimensions[1] * u.pix - 1 * u.pix)
-    assert_quantity_allclose(superpixel_map_sum.dimensions[0],
-                             aia171_test_map.dimensions[0] / dimensions[0] * u.pix - 1 * u.pix)
+    superpix_map = aia171_test_map_with_mask.superpixel(dimensions, offset=(1, 1) * u.pix)
+    assert superpix_map.dimensions[0] == expected_shape[0] - 1 * u.pix
+    assert superpix_map.dimensions[1] == expected_shape[1] - 1 * u.pix
 
     dimensions = (7, 9) * u.pix
-    superpixel_map_sum = aia171_test_map_with_mask.superpixel(dimensions, offset=(4, 4) * u.pix)
-    assert_quantity_allclose(
-        superpixel_map_sum.dimensions[0],
-        int((aia171_test_map.dimensions[0] / dimensions[0]).value) * u.pix - 1 * u.pix)
-    assert_quantity_allclose(
-        superpixel_map_sum.dimensions[1],
-        int((aia171_test_map.dimensions[1] / dimensions[1]).value) * u.pix - 1 * u.pix)
+    superpix_map = aia171_test_map_with_mask.superpixel(dimensions, offset=(4, 4) * u.pix)
+    expected_shape = np.round(input_dims * (1 * u.pix / dimensions))
+    assert superpix_map.dimensions[0] == expected_shape[0] - 1 * u.pix
+    assert superpix_map.dimensions[1] == expected_shape[1] - 1 * u.pix
 
 
 def test_superpixel_units(generic_map):
@@ -872,29 +889,37 @@ def calc_new_matrix(angle):
 
 
 def test_rotate(aia171_test_map):
-    rotated_map_1 = aia171_test_map.rotate(20 * u.deg)
-    rotated_map_2 = rotated_map_1.rotate(20 * u.deg)
+    # We use order=0 for many of these tests to minimize losing edge pixels due to interpolation
+    # with NaNs that are used as the default `missing` value
+
+    rotated_map_1 = aia171_test_map.rotate(20 * u.deg, order=0)
+    rotated_map_2 = rotated_map_1.rotate(20 * u.deg, order=0)
     np.testing.assert_allclose(rotated_map_1.rotation_matrix,
                                np.dot(aia171_test_map.rotation_matrix, calc_new_matrix(20).T))
     np.testing.assert_allclose(rotated_map_2.rotation_matrix,
                                np.dot(aia171_test_map.rotation_matrix, calc_new_matrix(40).T))
 
     # Rotation of a map by a non-integral multiple of 90 degrees expands the map
-    # and assigns the value of 0 to corner pixels. This results in a reduction
-    # of the mean for a map of all non-negative values.
+    # and assigns the value of NaN to corner regions. The mean will be approximately
+    # the same, although there will be slight change due to the loss of edge pixels
+    # due to interpolation with the NaNs.
     assert rotated_map_2.data.shape > rotated_map_1.data.shape > aia171_test_map.data.shape
-    np.testing.assert_allclose(rotated_map_1.data[0, 0], 0., atol=1e-7)
-    np.testing.assert_allclose(rotated_map_2.data[0, 0], 0., atol=1e-7)
-    assert rotated_map_2.mean() < rotated_map_1.mean() < aia171_test_map.mean()
+    assert np.isnan(rotated_map_1.data[0, 0])
+    assert np.isnan(rotated_map_2.data[0, 0])
+    np.testing.assert_allclose(aia171_test_map.mean(), rotated_map_1.mean(), rtol=5e-3)
+    np.testing.assert_allclose(aia171_test_map.mean(), rotated_map_2.mean(), rtol=5e-3)
 
     # A scaled-up map should have the same mean because the output map should be expanded
-    rotated_map_3 = aia171_test_map.rotate(0 * u.deg, order=3, scale=2)
+    rotated_map_3 = aia171_test_map.rotate(0 * u.deg, order=0, scale=2)
     np.testing.assert_allclose(aia171_test_map.mean(), rotated_map_3.mean(), rtol=1e-4)
 
-    # Mean and std should be equal for a 90 degree rotation
-    rotated_map_4 = aia171_test_map.rotate(90 * u.deg, order=3, scale=2)
-    np.testing.assert_allclose(rotated_map_3.mean(), rotated_map_4.mean(), rtol=1e-10)
-    np.testing.assert_allclose(rotated_map_3.std(), rotated_map_4.std(), rtol=1e-10)
+    # Mean and std should be equal for a 90 degree rotation as long as 1 pixel is cropped out on
+    # all sides
+    rotated_map_4 = aia171_test_map.rotate(90 * u.deg, order=0)
+    np.testing.assert_allclose(aia171_test_map.data[1:-1, 1:-1].mean(),
+                               rotated_map_4.data[1:-1, 1:-1].mean(), rtol=1e-10)
+    np.testing.assert_allclose(aia171_test_map.data[1:-1, 1:-1].std(),
+                               rotated_map_4.data[1:-1, 1:-1].std(), rtol=1e-10)
 
     # Rotation of a rectangular map by a large enough angle will change which dimension is larger
     aia171_test_map_crop = aia171_test_map.submap(
@@ -1180,6 +1205,17 @@ def test_quicklook(aia171_test_map):
         assert aia171_test_map._repr_html_() in html_string
 
 
+def test_dask_array(generic_map):
+    dask_array = pytest.importorskip('dask.array')
+    da = dask_array.from_array(generic_map.data, chunks=(1, 1))
+    pair_map = sunpy.map.Map(da, generic_map.meta)
+
+    # Check that _repr_html_ functions for a dask array
+    html_dask_repr = pair_map._repr_html_(compute_dask=False)
+    html_computed_repr = pair_map._repr_html_(compute_dask=True)
+    assert html_dask_repr != html_computed_repr
+
+
 @pytest.fixture
 def generic_map2(generic_map):
     generic_map.meta["CTYPE1"] = "HPLN-TAN"
@@ -1273,8 +1309,11 @@ def test_contour_units(simple_map):
         assert np.all(c1 == c2)
 
     # Percentage
-    contours_percent = simple_map.contour(100 * u.percent)
-    contours_ref = simple_map.contour(np.max(simple_map.data) * simple_map.unit)
+    contours_percent = simple_map.contour(50 * u.percent)
+    high = np.max(simple_map.data)
+    low = np.min(simple_map.data)
+    middle = high - (high - low) / 2
+    contours_ref = simple_map.contour(middle * simple_map.unit)
     for c1, c2 in zip(contours_percent, contours_ref):
         assert np.all(c1 == c2)
 
@@ -1427,13 +1466,14 @@ def test_rotation_rect_pixelated_data(aia171_test_map):
     rect_rot_map.peek()
 
 
+@pytest.mark.parametrize('method', _rotation_registry.keys())
 @figure_test
-def test_derotating_nonpurerotation_pcij(aia171_test_map):
+def test_derotating_nonpurerotation_pcij(aia171_test_map, method):
     # The following map has a a PCij matrix that is not a pure rotation
     weird_map = aia171_test_map.rotate(30*u.deg).superpixel([2, 1]*u.pix)
 
     # De-rotating the map by its PCij matrix should result in a normal-looking map
-    derotated_map = weird_map.rotate()
+    derotated_map = weird_map.rotate(method=method)
 
     fig = Figure(figsize=(8, 4))
 
@@ -1441,7 +1481,7 @@ def test_derotating_nonpurerotation_pcij(aia171_test_map):
     weird_map.plot(axes=ax1, title='Map with a non-pure-rotation PCij matrix')
 
     ax2 = fig.add_subplot(122, projection=derotated_map)
-    derotated_map.plot(axes=ax2, title='De-rotated map')
+    derotated_map.plot(axes=ax2, title=f'De-rotated map via {method}')
 
     return fig
 
@@ -1487,7 +1527,7 @@ def test_map_arithmetic_multiplication_division(aia171_test_map, value):
     check_arithmetic_value_and_units(new_map, value * aia171_test_map.quantity)
     new_map = aia171_test_map / value
     check_arithmetic_value_and_units(new_map, aia171_test_map.quantity / value)
-    with pytest.warns(RuntimeWarning, match='divide by zero encountered in'):
+    with pytest.warns(RuntimeWarning, match='divide by zero encountered in true_divide'):
         new_map = value / aia171_test_map
         check_arithmetic_value_and_units(new_map, value / aia171_test_map.quantity)
 
