@@ -2,12 +2,14 @@ import sys
 import platform
 import warnings
 from pathlib import Path
+from platform import python_version
 from functools import wraps
+from importlib.metadata import entry_points
 
 import matplotlib as mpl
 import matplotlib.pyplot as plt
-import pkg_resources
 import pytest
+from packaging.version import Version
 
 import astropy
 from astropy.wcs.wcs import FITSFixedWarning
@@ -41,24 +43,32 @@ if sys.maxsize > 2**32:
 else:
     SKIP_32 = True
 
-skip_windows = pytest.mark.skipif(platform.system() == 'Windows', reason="Windows.")
+skip_windows = pytest.mark.skipif(platform.system() == "Windows", reason="Windows.")
 skip_glymur = pytest.mark.skipif(SKIP_GLYMUR, reason="Glymur can not be imported.")
 skip_ana = pytest.mark.skipif(SKIP_ANA, reason="ANA is not available.")
-# Skip if the SunPy ASDF entry points are missing.
-asdf_entry_points = pytest.mark.skipif(not list(pkg_resources.iter_entry_points('asdf_extensions', 'sunpy')),
-                                       reason="No SunPy ASDF entry points.")
+if Version(python_version()) >= Version("3.10.0"):
+    asdf_entry_points = pytest.mark.skipif(
+        not entry_points().select(group="asdf.resource_mappings", name="sunpy"),
+        reason="No SunPy ASDF entry points.",
+    )
+else:
+    asdf_entry_points = pytest.mark.skipif(
+        not all(
+            [
+                enter_point.name == "sunpy"
+                for enter_point in entry_points()["asdf.resource_mappings"]
+            ]
+        ),
+        reason="No SunPy ASDF entry points.",
+    )
 
 
 @pytest.fixture
 def warnings_as_errors(request):
     warnings.simplefilter('error')
-
     request.addfinalizer(lambda *args: warnings.resetwarnings())
 
 
-new_hash_library = {}
-
-
 def get_hash_library_name():
     """
     Generate the hash library name for this env.
@@ -90,7 +100,6 @@ def figure_test(test_function):
     hash_library_name = get_hash_library_name()
     hash_library_file = Path(__file__).parent / hash_library_name
 
-    @pytest.mark.remote_data
     @pytest.mark.mpl_image_compare(hash_library=hash_library_file,
                                    savefig_kwargs={'metadata': {'Software': None}},
                                    style='default')
@@ -116,7 +125,6 @@ def no_vso(f):
         res = f(*args, **kwargs)
         Fido.registry[VSOClient] = VSOClient._can_handle_query
         return res
-
     return wrapper
 
 
